@@ -25,14 +25,15 @@ def post_task_status(hisId, jobState, jobResult, master_data):
     url = urljoin(master_data["server"], "/worker/PutJobResult")
     try:
         r = requests.post(url=url, json=data, headers=headers)
-    except Exception as e:
-        print("error alert:", e)
-    else:
         response_text = json.loads(str(r.text))
         if response_text["statusCode"] == "00":
             print("update task status successful")
             return 0
-        print("post task status failed", r.text)
+        print("post task status failed: ", r.text)
+    except Exception as e:
+        print("post_task_status error")
+        raise e
+        
 
 def get_task(master_data):
     data = {"sessionId": master_data['sessionId'], "timestamp": str(round(time.time()*1000000)), 
@@ -72,14 +73,14 @@ def task_timeout(func):
 def task_consumer(task, master_data):
     try:
         task_dic = json.loads(task)
-    except Exception as e:
-        print("task_consumer error", e)
-    else:
         his_id = task_dic["content"]["his_id"]
         job_content = task_dic["content"]["job_content"]
         r = subprocess.run(job_content, shell=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
-        # print("comand output: ", r.stdout)
+        print("comand output: ", r.stdout)
         post_task_status(his_id, r.returncode, str(r.stdout), master_data)
+    except Exception as e:
+        print("task_consumer error", e)
+        
 
 def task_producer(queue, master_data):
     while True:
@@ -95,7 +96,7 @@ def task_runner(master_data):
     print("task_runner:", master_data)
     print("---------------")
     write_pid(current_process().pid, task_pidfile)
-    queue = Queue(maxsize=0)
+    queue = Queue(maxsize=50)
     producer = Thread(target=task_producer, args=(queue, master_data))
     producer.start()
     while True:
