@@ -51,8 +51,8 @@ def register(server, label, tag, timeout):
 @click.option("--sessionId", required=True, help="session id")
 def run(server, workerid, sessionid, timeout):
     master_data = {"server": server, "workerId": workerid, "sessionId": sessionid, "timeout": timeout}
-    task_process = Process(target=task_runner, daemon=True, args=(master_data,))
-    publish_process = Process(target=publish_runner, daemon=True, args=(master_data,))
+    task_process = Process(target=task_runner, args=(master_data,))
+    publish_process = Process(target=publish_runner, args=(master_data,))
     task_process.start()
     publish_process.start()
     write_pid(current_process().pid, sync_pidfile)
